#[non_exhaustive]pub enum HookError {
Io {
path: PathBuf,
source: Error,
},
InvalidConfiguration {
path: PathBuf,
message: String,
},
Json(Error),
MissingRepositoryAlias(PathBuf),
InvalidSystemTime,
UnknownHost(String),
MissingPrompt,
}Expand description
Error returned by host installation and routing APIs.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
Filesystem operation failed.
InvalidConfiguration
Host JSON configuration was malformed or had an incompatible shape.
Json(Error)
Serialization failed.
MissingRepositoryAlias(PathBuf)
The repository root has no final component from which to derive an alias.
InvalidSystemTime
System time is earlier than the Unix epoch.
UnknownHost(String)
A command-line host identifier is unknown.
MissingPrompt
A routing event omitted a textual top-level prompt.