pub struct InstallReport {
pub changed: bool,
pub host_file: PathBuf,
pub state_file: PathBuf,
pub gitignore_path: Option<PathBuf>,
pub gitignore_updated: bool,
pub backups: Vec<PathBuf>,
pub warnings: Vec<String>,
pub limitation: Option<String>,
}Expand description
Result of an installation attempt.
Fields
changed: boolWhether any managed file changed.
host_file: PathBufHost configuration or guidance file managed by this installation.
state_file: PathBufManaged state file written with restrictive permissions.
gitignore_path: Option<PathBuf>Repository-local Git ignore file when the root belongs to a Git worktree.
gitignore_updated: boolWhether installation added the generated-state rule.
backups: Vec<PathBuf>Files whose previous contents were backed up.
warnings: Vec<String>Non-fatal duplicate or compatibility observations.
limitation: Option<String>Host limitation when a stable prompt-hook protocol cannot carry guidance.